var indexSectionsWithContent =
{
  0: "0123456789abcdefghiklmnopqrstuvwx–“…≤≥",
  1: "rx",
  2: "x",
  3: "rx",
  4: "lmorv",
  5: "x",
  6: "rx",
  7: "rx",
  8: "x",
  9: "acdfhiklmnpqrsvx",
  10: "0123456789abcdefghiklmnopqrstuvwx–“…≤≥"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "files",
  3: "functions",
  4: "variables",
  5: "typedefs",
  6: "enums",
  7: "enumvalues",
  8: "defines",
  9: "groups",
  10: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Data Structures",
  2: "Files",
  3: "Functions",
  4: "Variables",
  5: "Typedefs",
  6: "Enumerations",
  7: "Enumerator",
  8: "Macros",
  9: "Modules",
  10: "Pages"
};

